@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2012 Red Hat, Inc.
+ * Copyright (C) 2001-2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -86,7 +86,20 @@ static PyObject * doImplantIsoMD5Sum(PyObject * s, PyObject * args) {
     return Py_BuildValue("i", rc);
 }
 
+#ifdef PYTHON_ABI_VERSION
+static struct PyModuleDef pyisomd5sum = {
+    PyModuleDef_HEAD_INIT,
+    "pyisomd5sum",
+    NULL,
+    -1,
+    isomd5sumMethods
+};
 
+PyMODINIT_FUNC PyInit_pyisomd5sum(void) {
+    return PyModule_Create(&pyisomd5sum);
+}
+#else
 void initpyisomd5sum(void) {
     (void)Py_InitModule("pyisomd5sum", isomd5sumMethods);
 }
+#endif
